import setuptools
from setuptools import setup

setup(name='Wide-Residual-Network',
      version='1.1',
      description="This package is for creating a wide residual convolutional neural network with keras and tensorflow as backend. This architecture was first introduced in the paper on https://arxiv.org/abs/1605.07146.",
      author="Patrick Brus",
      license="MIT",
      url="https://github.com/patrickbrus/Wide-Residual-Network-Package",
      packages=setuptools.find_packages(),
      zip_safe=False)